@@ -2,11 +2,16 @@ package WebService::Stripe;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.0900'; # VERSION
+our $VERSION = '0.1000'; # VERSION
 
 use Carp qw(croak);
+use HTTP::Request::Common qw( POST );
 use Method::Signatures;
-use constant { MARKETPLACES_MIN_VERSION => '2014-11-05' };
+use constant {
+    FILE_UPLOADS_URL         => 'https://uploads.stripe.com/v1/files',
+    FILE_PURPOSE_ID_DOCUMENT => 'identity_document',
+    MARKETPLACES_MIN_VERSION => '2014-11-05',
+};
 
 has api_key => (
     is       => 'ro',
@@ -27,18 +32,22 @@ method BUILD(@args) {
     $self->ua->default_header( 'Stripe-Version' => $self->version );
 }
 
-method next(HashRef $thing, HashRef :$query) {
+method next(HashRef $thing, HashRef :$query, HashRef :$headers) {
     $query ||= {};
     return undef unless $thing->{has_more};
     my $starting_after = $thing->{data}[-1]{id} or return undef;
     return $self->get( $thing->{url},
-        { %$query, starting_after => $starting_after } );
+        { %$query, starting_after => $starting_after }, headers => $headers );
 }
 
 method create_customer(Maybe[HashRef] $data, :$headers) {
     return $self->post( "/v1/customers", $data, headers => $headers );
 }
 
+method get_application_fee(Str $id, :$headers) {
+    return $self->get( "/v1/application_fees/$id", {}, headers => $headers );
+}
+
 method get_balance(:$headers) {
     return $self->get( "/v1/balance", {}, headers => $headers );
 }
@@ -107,6 +116,18 @@ method update_account(Str $id, HashRef :$data!, :$headers) {
     return $self->post( "/v1/accounts/$id", $data, headers => $headers );
 }
 
+method upload_identity_document(HashRef|Str $account_id, Str $filepath) {
+    return $self->req(
+        POST FILE_UPLOADS_URL,
+        Stripe_Account => ( ref $account_id ? $account_id->{id}: $account_id ),
+        Content_Type   => 'form-data',
+        Content        => [
+            purpose => FILE_PURPOSE_ID_DOCUMENT,
+            file    => [ $filepath ],
+        ],
+    );
+}
+
 method add_bank(HashRef $data, Str :$account_id!, :$headers) {
     return $self->post(
         "/v1/accounts/$account_id/bank_accounts", $data, headers => $headers );
@@ -176,7 +197,7 @@ WebService::Stripe - Stripe API bindings
 
 =head1 VERSION
 
-version 0.0900
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -335,6 +356,22 @@ Adds a new funding source (credit card) to an existing customer.
 
     update_account($id, data => $data)
 
+=head2 upload_identity_document( $accountID, $absPathToPhoto )
+
+Uploads a photo ID to an account.
+
+Example:
+
+    my $account = $stripe->create_account({
+        managed => 'true',
+        country => 'CA',
+    });
+
+    my $file = $stripe->upload_identity_document( $account, '/tmp/photo.png' );
+    $stripe->update_account( $account->{id}, data => {
+        legal_entity[verification][document] => $file->{id},
+    });
+
 =head2 add_bank
 
     add_bank($data, account_id => $account_id)
